%global	with_ldap	1
%global	with_mysql	1
%global	with_gssapi	1
%global	with_sasl	0
%global	with_pgsql	0
%{?_without_ldap: %{expand: %%global with_ldap 0}}
%{?_without_mysql: %{expand: %%global with_mysql 0}}
%{?_without_gssapi: %{expand: %%global with_gssapi 0}}
%{?_with_sasl: %{expand: %%global with_sasl 1}}
%{?_with_pgsql: %{expand: %%global with_pgsql 1}}
# TODO
# add configurable ssl support, unfortunately --without-ssl doesn't work if
# openssl-devel package is installed

Summary:	Secure IMAP and POP3 server
Name: 		dovecot
Version:	1.0.13
Release:	%mkrel 1
License:	MIT and LGPLv2 and BSD-like and Public Domain
Group:		System/Servers
URL:		http://dovecot.org
Source0:	http://dovecot.org/releases/%{name}-%{version}.tar.gz
Source1:	http://dovecot.org/releases/%{name}-%{version}.tar.gz.sig
Source2:	%{name}-pamd
Source3:	%{name}-init
Source4:	http://dovecot.org/tools/migration_wuimp_to_dovecot.pl
Source5:	http://dovecot.org/tools/mboxcrypt.pl
# sieve plugin. Must be updated when minor version increases.
Source6:	%{name}-sieve-1.0.2.tar.gz
Patch:		dovecot-conf-ssl.patch
Provides:	imap-server pop3-server
Provides:	imaps-server pop3s-server
Requires(pre):	rpm-helper >= 0.21
Requires(post):	rpm-helper >= 0.19
Requires(preun):	rpm-helper >= 0.19
Requires(postun):	rpm-helper >= 0.19
BuildRequires:	pam-devel
BuildRequires:	openssl-devel
%if %{with_ldap}
BuildRequires:	openldap-devel
%endif
%if %{with_sasl}
BuildRequires:	libsasl-devel
%endif
%if %{with_mysql}
BuildRequires:	mysql-devel
%endif
%if %{with_pgsql}
BuildRequires:	postgresql-devel
%endif
%if %{with_gssapi}
BuildRequires:	gssglue-devel
BuildRequires:	krb5-devel
%endif
BuildRequires:  rpm-helper >= 0.21
BuildRoot:	%{_tmppath}/%{name}-%{version}

%description
Dovecot is an IMAP and POP3 server for Linux/UNIX-like systems, written with
security primarily in mind. Although it's written with C, it uses several
coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and it's fully
compatible with UW-IMAP and Courier IMAP servers as well as mail clients
accessing the mailboxes directly.

This package has some configurable build options:

 --without ldap		- build without LDAP (default enabled)
 --without mysql	- build without MySQL support (default enabled)
 --without gssapi	- build without GSSAPI support (default enabled)
 --with sasl		- build with Cyrus SASL 2 library support
 --with pgsql		- build with PostgreSQL support

%package	devel
Summary:	Devel files for Dovecot IMAP and POP3 server
Group:		Development/C

%description	devel
Dovecot is an IMAP and POP3 server for Linux/UNIX-like systems, written with
security primarily in mind. Although it's written with C, it uses several
coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and it's fully
compatible with UW-IMAP and Courier IMAP servers as well as mail clients
accessing the mailboxes directly.

This package contains development files for dovecot.

%prep

%setup -q -a 6
# Bug #27491
%patch -p1 -b .sslfix

%build
%serverbuild
%configure2_5x \
    --with-ssl=openssl \
    --with-ssldir="%{_sysconfdir}/ssl/%{name}" \
    --with-moduledir="%{_datadir}/%{name}/" \
%if %{with_ldap}
    --with-ldap \
%endif
%if %{with_pgsql}
    --with-sql \
    --with-pgsql \
%endif
%if %{with_mysql}
    --with-sql \
    --with-mysql \
%endif
%if %{with_sasl}
    --with-cyrus-sasl2 \
%endif
%if %{with_gssapi}
    --with-gssapi
%endif
%make

#build sieve plugin
pushd dovecot-sieve-1.0.2
%configure2_5x --with-dovecot=../
%make
popd

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}%{_datadir}/%{name}

%makeinstall_std
pushd dovecot-sieve-1.0.2
%makeinstall_std
popd
mkdir -p %{buildroot}%{_sysconfdir}/pam.d \
	%{buildroot}%{_initrddir} \
	%{buildroot}%{_var}/%{_lib}/%{name}
cat %{SOURCE2} > %{buildroot}%{_sysconfdir}/pam.d/%{name}
cat %{SOURCE3} > %{buildroot}%{_initrddir}/%{name}
cp dovecot-example.conf %{buildroot}%{_sysconfdir}/dovecot.conf
cp %{SOURCE4} .
cp %{SOURCE5} .
# placed in doc
rm -f %{buildroot}%{_sysconfdir}/dovecot*-example.conf

# Clean up buildroot
rm -rf %{buildroot}%{_datadir}/doc/dovecot/

%pre
%_pre_useradd dovecot %{_var}/%{_lib}/%{name} /bin/false
%_pre_groupadd dovecot dovecot

%post
%_post_service dovecot
%_create_ssl_certificate dovecot

%preun
%_preun_service dovecot

%postun
%_postun_userdel dovecot
%_postun_groupdel dovecot

%clean
rm -rf %{buildroot}

%files
%defattr(0755, root, root, 0755)
%{_initrddir}/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*
%{_sbindir}/*
%attr(0700,root,root) %dir %{_var}/%{_lib}/%{name}
%defattr(0644,root,root,0755)
%doc AUTHORS ChangeLog COPYING* NEWS README TODO
%doc doc/*.conf doc/*.sh doc/*.txt doc/*.cnf
%doc mboxcrypt.pl migration_wuimp_to_dovecot.pl
%attr(0640,root,root) %config(noreplace) %{_sysconfdir}/dovecot.conf
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.la
%{_datadir}/%{name}/*.so
%{_datadir}/%{name}/pop3/*.so
%{_datadir}/%{name}/lda/*.so
%{_datadir}/%{name}/lda/*.*a
%{_datadir}/%{name}/imap/*.so
%{_datadir}/%{name}/imap/*.la

%files devel
%defattr(0755, root, root, 0755)
%{_datadir}/%{name}/*.a
%{_datadir}/%{name}/imap/*.a


%changelog
* Mon Mar 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.13-1mdv2008.1
+ Revision: 183490
- 1.0.13 (Minor security fixes)

* Thu Mar 06 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.12-2mdv2008.1
+ Revision: 180930
- fix #38615

* Thu Mar 06 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.12-1mdv2008.1
+ Revision: 180856
- 1.0.12

* Fri Feb 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.10-4mdv2008.1
+ Revision: 168821
- versionned build dependency on rpm-helper

* Tue Jan 29 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.10-3mdv2008.1
+ Revision: 159934
- use new create ssl certificate helper macro interface

* Mon Jan 28 2008 Adam Williamson <awilliamson@mandriva.com> 1.0.10-2mdv2008.1
+ Revision: 159425
- add sieve plugin (#32581)

* Tue Jan 15 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.10-1mdv2008.1
+ Revision: 153290
- 1.0.10

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.9-2mdv2008.1
+ Revision: 137504
- rebuilt against openldap-2.4.7 libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Jérôme Soyer <saispo@mandriva.org> 1.0.9-1mdv2008.1
+ Revision: 119730
- New release 1.0.9

* Tue Dec 04 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.8-1mdv2008.1
+ Revision: 115393
- 1.0.8

* Tue Nov 06 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.7-1mdv2008.1
+ Revision: 106384
- 1.0.7

* Mon Sep 17 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.5-1mdv2008.0
+ Revision: 89292
- 1.0.5

* Fri Aug 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.3-4mdv2008.0
+ Revision: 64673
- use ssl certs creation helpers

  + Tibor Pittich <tibor@mandriva.com>
    - fixed Bug #27491 and #27561

* Thu Aug 16 2007 Tibor Pittich <tibor@mandriva.com> 1.0.3-2mdv2008.0
+ Revision: 64136
- increase release number
- really enable ldap support
- fix with/without rpm build options, fix dexcription

* Wed Aug 15 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.3-1mdv2008.0
+ Revision: 63642
- 1.0.3

* Thu Aug 02 2007 Adam Williamson <awilliamson@mandriva.com> 1.0.2-4mdv2008.0
+ Revision: 58315
- BuildRequires krb5-devel for gssapi build
- use Fedora licensing policy (licensing on this app is insane, this is a good way to handle it)

* Fri Jul 27 2007 Adam Williamson <awilliamson@mandriva.com> 1.0.2-3mdv2008.0
+ Revision: 56127
- build with support for GSSAPI authentication (bug #32112)

* Tue Jul 17 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.2-2mdv2008.0
+ Revision: 52872
- fix rpm-helper Requires(post,preun) and such
- fix deps
- 1.0.2

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 1.0.1-2mdv2008.0
+ Revision: 45127
- using serverbuild macro (-fstack-protector-all)

  + Adam Williamson <awilliamson@mandriva.com>
    - adjust ssl stuff as advised by guillaume (#27561)

* Fri Jun 15 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.1-1mdv2008.0
+ Revision: 40141
- 1.0.1

* Tue Jun 12 2007 Adam Williamson <awilliamson@mandriva.com> 1.0.0-2mdv2008.0
+ Revision: 38341
- install /etc/pki/dovecot/dovecot-openssl.cnf (bug #27561)
- argh, wrong branch! revert
- import 2007 package to updates

* Tue May 01 2007 Michael Scherer <misc@mandriva.org> 1.0.0-1mdv2008.0
+ Revision: 19904
- upgrade to 1.0.0 ( at last )

* Sat Apr 21 2007 Anssi Hannula <anssi@mandriva.org> 1.0.rc26-2mdv2008.0
+ Revision: 16707
- migrate away from deprecated pam_stack.so


* Tue Mar 13 2007 Jérôme Soyer <saispo@mandriva.org> 1.0.rc26-1mdv2007.1
+ Revision: 142202
- New RC

* Sun Mar 04 2007 Michael Scherer <misc@mandriva.org> 1.0.rc25-1mdv2007.1
+ Revision: 131924
- update to 1.0.rc25

* Fri Jan 12 2007 Michael Scherer <misc@mandriva.org> 1.0.rc17-1mdv2007.1
+ Revision: 107793
- upgrade to rc17

* Wed Nov 29 2006 Michael Scherer <misc@mandriva.org> 1.0.rc15-1mdv2007.1
+ Revision: 88778
- use default upstream configuration file
- bunzip patch
- upgrade to 1.0.rc15
- Import dovecot

* Tue Sep 05 2006 Jerome Soyer <saispo@mandriva.org> 1.0.rc7.1mdv2007.0
- new version

* Thu Jul 13 2006 Nicolas Chipaux <chipaux@mandriva.com> 1.0.rc2.1mdv2007.0
- new version
- split in devel rpm

* Mon Jun 26 2006 Nicolas Chipaux <chipaux@mandriva.com> 1.09.beta9.1mdv2007.0
- new version

* Tue May 30 2006 Jerome Soyer <saispo@mandriva.org> 0.99.14-4mdv2007.0
- CVE-2006-2414 
- use mkrel

* Wed Nov 30 2005 Oden Eriksson <oeriksson@mandriva.com> 0.99.14-3mdk
- rebuilt against openssl-0.9.8a

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 0.99.14-2mdk
- rebuilt against new openldap-2.3.6 libs

* Fri Mar 18 2005 Michael Scherer <misc@mandrake.org> 0.99.14-1mdk
- New release 0.99.14
- better summary
- add some tools in %%doc

* Fri Feb 04 2005 Michael Scherer <misc@mandrake.org> 0.99.12-2mdk
- Rebuild new ldap

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.99.12-1mdk
- New release 0.99.12

* Wed Aug 11 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 0.99.10.9-2mdk
- fix init script to make rpmlint happy
- create switches to allow/deny some features and and describe it in
  description
- update url
- by default disable pgsql support, added configurable support for mysql
- change provides to pop3-server and add imaps and pop3s-server provides
- minimalize number of nonstandard permission in files
- some other spec changes, macroszification

* Tue Aug 10 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 0.99.10.9-1mdk
- 0.99.10.9

* Thu Jul 15 2004 Michael Scherer <misc@mandrake.org> 0.99.10.7-1mdk 
- 0.99.10.7
- rpmbuildupdate aware

* Wed Jul 14 2004 Michael Scherer <misc@mandrake.org> 0.99.10.6-1mdk
- New release 0.99.10.6
- replaced the patch on conf by a source file
- fix BuildRequires, and init script ( from Michael Reinsch <mr@uue.org> )
- remove implicit requires, added new provides scheme
- remove service restart on upgrade, as it is already done by spec-helper

